@@ -94,7 +94,7 @@
   #:use-module (ice-9 regex)
   #:use-module (ice-9 pretty-print)
   #:re-export (*nyacc-version*)
-  #:version (1 08 7))
+  #:version (1 09 0))
 
 (define fh-cpp-defs
   (cond
@@ -856,10 +856,14 @@
     (else (fherr "can't deal with this alignment: ~S" align))))
 
 ;; assumes fields are unitized
+;; this does not do the job right because needs to include double
+;; if that is used
 (define (bounding-mtail-for-union-fields fields)
   (let loop ((btail #f) (mxsz 0) (mxal 0) (flds fields))
     (if (null? flds) btail
-	(let ((mtail (cdr (udecl->mdecl (car flds)))))
+	(let* ((udecl (car flds))
+               (xdecl (expand-typerefs (car flds) (*udict*)))
+               (mtail (cdr (udecl->mdecl xdecl))))
 	  (call-with-values (lambda () (sizeof-mtail mtail (*udict*)))
 	    (lambda (sz al)
 	      (if (> sz mxsz)
